//-*-c++-*-
#ifndef _SPRINGELECTRICAL_H
#define _SPRINGELECTRICAL_H
#include <cmath>
#include <tulip/TulipPlugin.h>

class SpringElectrical:public Layout
{ 
public:
  SpringElectrical(const PropertyContext &);
  ~SpringElectrical();
  bool run();
  bool check(std::string &);
  void reset();

};

#endif









